"""Contains classes for different representations of test scores.

It also contains score collections such as arrays and matrices.
"""

from .base import ErrorScore, Score, score_logger
from .complete import *
from .incomplete import *


